==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/LekRealizacjaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class LekRealizacjaKey extends GenericDPSObject {
    /**
     * LEK_REALIZACJA.REALIZACJA_RECEPTA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long realizacjaReceptaId;

    /**
     * LEK_REALIZACJA.KOD_BAZYL
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long kodBazyl;

    /**
     * LEK_REALIZACJA.NIEZREALIZOWANY
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean niezrealizowany;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return LEK_REALIZACJA.REALIZACJA_RECEPTA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getRealizacjaReceptaId() {
        return realizacjaReceptaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * LEK_REALIZACJA.REALIZACJA_RECEPTA_ID
     *
     * @param realizacjaReceptaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRealizacjaReceptaId(Long realizacjaReceptaId) {
        this.realizacjaReceptaId = realizacjaReceptaId;
    }

    /**
     * @return LEK_REALIZACJA.KOD_BAZYL
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getKodBazyl() {
        return kodBazyl;
    }

    /**
     * LEK_REALIZACJA.KOD_BAZYL
     *
     * @param kodBazyl
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKodBazyl(Long kodBazyl) {
        this.kodBazyl = kodBazyl;
    }

    /**
     * @return LEK_REALIZACJA.NIEZREALIZOWANY
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getNiezrealizowany() {
        return niezrealizowany;
    }

    /**
     * LEK_REALIZACJA.NIEZREALIZOWANY
     *
     * @param niezrealizowany
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNiezrealizowany(Boolean niezrealizowany) {
        this.niezrealizowany = niezrealizowany;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        LekRealizacjaKey other = (LekRealizacjaKey) that;
        return (this.getRealizacjaReceptaId() == null ? other.getRealizacjaReceptaId() == null : this.getRealizacjaReceptaId().equals(other.getRealizacjaReceptaId()))
            && (this.getKodBazyl() == null ? other.getKodBazyl() == null : this.getKodBazyl().equals(other.getKodBazyl()))
            && (this.getNiezrealizowany() == null ? other.getNiezrealizowany() == null : this.getNiezrealizowany().equals(other.getNiezrealizowany()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getRealizacjaReceptaId() == null) ? 0 : getRealizacjaReceptaId().hashCode());
        result = prime * result + ((getKodBazyl() == null) ? 0 : getKodBazyl().hashCode());
        result = prime * result + ((getNiezrealizowany() == null) ? 0 : getNiezrealizowany().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", realizacjaReceptaId=").append(realizacjaReceptaId);
        sb.append(", kodBazyl=").append(kodBazyl);
        sb.append(", niezrealizowany=").append(niezrealizowany);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/LekRealizacjaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class LekRealizacjaKey extends GenericDPSObject {
    /**
     * LEK_REALIZACJA.REALIZACJA_RECEPTA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long realizacjaReceptaId;

    /**
     * LEK_REALIZACJA.KOD_BAZYL
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long kodBazyl;

    /**
     * LEK_REALIZACJA.NIEZREALIZOWANY
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean niezrealizowany;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return LEK_REALIZACJA.REALIZACJA_RECEPTA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getRealizacjaReceptaId() {
        return realizacjaReceptaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:46
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * LEK_REALIZACJA.REALIZACJA_RECEPTA_ID
     *
     * @param realizacjaReceptaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRealizacjaReceptaId(Long realizacjaReceptaId) {
        this.realizacjaReceptaId = realizacjaReceptaId;
    }

    /**
     * @return LEK_REALIZACJA.KOD_BAZYL
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getKodBazyl() {
        return kodBazyl;
    }

    /**
     * LEK_REALIZACJA.KOD_BAZYL
     *
     * @param kodBazyl
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKodBazyl(Long kodBazyl) {
        this.kodBazyl = kodBazyl;
    }

    /**
     * @return LEK_REALIZACJA.NIEZREALIZOWANY
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getNiezrealizowany() {
        return niezrealizowany;
    }

    /**
     * LEK_REALIZACJA.NIEZREALIZOWANY
     *
     * @param niezrealizowany
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNiezrealizowany(Boolean niezrealizowany) {
        this.niezrealizowany = niezrealizowany;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        LekRealizacjaKey other = (LekRealizacjaKey) that;
        return (this.getRealizacjaReceptaId() == null ? other.getRealizacjaReceptaId() == null : this.getRealizacjaReceptaId().equals(other.getRealizacjaReceptaId()))
            && (this.getKodBazyl() == null ? other.getKodBazyl() == null : this.getKodBazyl().equals(other.getKodBazyl()))
            && (this.getNiezrealizowany() == null ? other.getNiezrealizowany() == null : this.getNiezrealizowany().equals(other.getNiezrealizowany()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getRealizacjaReceptaId() == null) ? 0 : getRealizacjaReceptaId().hashCode());
        result = prime * result + ((getKodBazyl() == null) ? 0 : getKodBazyl().hashCode());
        result = prime * result + ((getNiezrealizowany() == null) ? 0 : getNiezrealizowany().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", realizacjaReceptaId=").append(realizacjaReceptaId);
        sb.append(", kodBazyl=").append(kodBazyl);
        sb.append(", niezrealizowany=").append(niezrealizowany);
        sb.append("]");
        return sb.toString();
    }
}
